@@ -2,20 +2,22 @@
 
 package Dancer::Plugin::Authorize;
 BEGIN {
-  $Dancer::Plugin::Authorize::VERSION = '0.1010';
+  $Dancer::Plugin::Authorize::VERSION = '0.1110';
 }
 use strict;
 use warnings;
 use Dancer qw/:syntax/;
 use Dancer::Plugin;
 
-my  $settings = plugin_setting;
+our $settings = plugin_setting;
 
 register auth => sub { return Dancer::Plugin::Authorize->new(@_) };
 
 
 sub new {
     my $class = shift;
+    my @credentials = @_;
+    
     my $credentialsClass =
     __PACKAGE__ . "::Credentials::" . $settings->{credentials}->{class};
     {
@@ -25,7 +27,14 @@ sub new {
         $credentialsClass =~ s/\//::/g;
     }
     
+    my $self = {};
+    bless $self, $class;
+    
+    # return $credentialsClass->new
+    # unless scalar @credentials;
+    
     my $user = session('user');
+    
     if ($user) {
         # reset authentication errors
         $user->{error} = [];
@@ -43,12 +52,11 @@ sub new {
     
     session 'user' => $user;
     
-    return $credentialsClass->new unless scalar @_;
+    #return $credentialsClass->new->authorize($settings->{credentials}->{options}, @credentials)
+    #? $self : undef;
     
-    my $self = {};
-    bless $self, $class;
-    return $credentialsClass->new->authorize($settings->{credentials}->{options}, @_)
-    ? $self : undef;
+    $credentialsClass->new->authorize($settings->{credentials}->{options}, @credentials);
+    return $self;
 }
 
 sub asa {
@@ -121,14 +129,14 @@ Dancer::Plugin::Authorize - Dancer Authentication, Security and Role-Based Acces
 
 =head1 VERSION
 
-version 0.1010
+version 0.1110
 
 =head1 SYNOPSIS
 
     post '/login' => sub {
         
         my $auth = auth(params->{user}, params->{pass});
-        if ($auth) {
+        if (! $auth->errors) {
         
             if ($auth->asa('guest')) {
                 ...
