@@ -2,13 +2,12 @@
 
 package Dancer::Plugin::Authorize::Credentials::SQLite;
 BEGIN {
-  $Dancer::Plugin::Authorize::Credentials::SQLite::VERSION = '0.1010';
+  $Dancer::Plugin::Authorize::Credentials::SQLite::VERSION = '0.1110';
 }
 
 use strict;
 use warnings;
 use base qw/Dancer::Plugin::Authorize::Credentials/;
-use Dancer;
 use Dancer::Plugin::Database;
 
 
@@ -28,11 +27,10 @@ sub authorize {
             return 0;
         }
         
-        my $sth = database($options->{handle})->prepare(
+        my $dbh = database($options->{handle});
+        my $sth = $dbh->prepare(
             'SELECT * FROM users WHERE login = ? AND password = ?',
-        );  $sth->execute($login, $password) if $sth;
-        
-        die 'Can\'t connect to the database' unless $sth;
+        ); $sth->execute($login, $password) if $sth;
         
         my $accounts = $sth->fetchrow_hashref;
     
@@ -53,7 +51,7 @@ sub authorize {
         }
         else {
             $self->errors('login and/or password is invalid');
-            return undef;
+            return 0;
         }
     
     }
@@ -69,11 +67,11 @@ sub authorize {
         }
         else {
             $self->errors('you are not authorized', 'your session may have ended');
-            return undef;
+            return 0;
         }
         
     }
-    return undef;
+    return 0;
 }
 
 1;
@@ -86,7 +84,7 @@ Dancer::Plugin::Authorize::Credentials::SQLite - Dancer::Plugin::Authorize authe
 
 =head1 VERSION
 
-version 0.1010
+version 0.1110
 
 =head1 SYNOPSIS
 
